; ----------------------------------------------------------------------
;  SysReq.Inc - Data definitions

; System Equates
BIOSINT        equ     15h     ; BIOS Spec Int
BIOSNEW        equ     85h     ; redirected 15h Bios Ext'd
PSCRNINT       equ     5h      ; Print Screen
PSCRNEW        equ     86h     ; redirected 5h Print
UTICKINT       equ     1Ch     ; Bios User Ticker 18.2/Sec
UTICKNEW       equ     8Ch     ; redirected 1Ch Ticker
ALARMINT       equ     4Ah     ; AT User Alarm
ALARMNEW       equ     8Ah     ; redirected 4Ah Alarm
ENTERINT       equ     8Eh     ; 'Press ENTER' Int

DOSBOOT        equ     19h     ; DOS Bootstrap
DOS            equ     21h     ; DOS Sys Func Req Int

BIOSVID        equ     10h     ; BIOS Video Int
BIOSEQU        equ     11h     ;  "   Equipment Flags
BIOSMEM        equ     12h     ;  "   Memory Size
BIOSDSK        equ     13h     ;  "   Floppy Disk
BIOSCOM        equ     14h     ;  "   Communications
BIOSEXT        equ     15h     ;  "   Extended
BIOSKBD        equ     16h     ;  "   Keyboard
BIOSPRT        equ     17h     ;  "   Printer
BIOSRTC        equ     1Ah     ;  "   Real Time Clock

; ----------------------------------------------------------------------
; Data Variables
               .DATA

;  Screen Line Data (no Attr)    Actual Len = Cols + 2 (Cr,Lf)
DTASCREEN      Label   Byte    ; 132 + 2 = 134
DTA_VLI        Equ     256

; Window save area (Msg Rows x Len x 2 = Bytes)  13k Max if 132x50
;   12 rows x 80 cols x 2 bytes = 1920 Bytes
;   25 rows x 80 cols x 2 bytes = 4000 Bytes  4k
DTASAVE        Label   Byte    ; 12 Rows x 80 Cols x 2
DTASLEN        Equ     1920

               DB      2048 DUP(0)  ; 2k Buffer for everybody

; PASSBUFF  PassThru Buffer Area (also Macro save area)
PASSBUFF       Label   Byte    ; PassThru Buffer
PBADDR         DD      PASSBUFF  ; Far Ptr to Here!
PBTEXT         DB      '  d:\Path  :  '
PBDRIVE        DB      'C'     ; Cur Drive
               DB      ':\'
PBPATH         DB      64 DUP (0)  ; Cur Path
PBFSPEC        DB      12 DUP (0)  ; FileName.Ext
PBFH           DW      0       ; File Handle
PBDTA          DW      0       ; Disk Transfer Addr
PBSDTA         DW      0       ; DTA Seg
PBFSA          DW      0       ; FSpec Addr
DOSRECUR       DD      0       ; Ptr to DOS Recursion Cntr

RUNDS          DW      0       ; Runtime Data Seg
RUNES          DW      0       ;  "      Extra Seg
RUNCS          DW      0       ;  "      Code Seg
RUNSS          DW      0       ;  "      Stack Seg
RUNSP          DW      0       ;  "       "    Ptr
PSPES          DW      0       ;  "      PSP Seg

IRADDR         DW      IRDATA  ; Reg Save Addr Index (+-36)
IRDATA         DW      144 DUP(0)  ; Reg Save Table (16 x18b @ 9R16)
               DW      0FFFFh
SAVESS         DW      0       ; Int 15h
SAVESP         DW      0

FLAGS          DB      0       ; BIOS Save
KEYCODE        DW      0       ; Save Scan Alt+SysRQ
REGFLAG        DB      0       ; 1=Extra Pgm Stk Frame to Restore if Err
TSRFLAG        DB      0FFh    ; 1=Resident, 2=Interrupt, 3=Aborted, FFh=DOS
TICKFLAG       DB      0       ; " ...
ALMFLAG        DB      0       ; 1=Int 4Ah Active
HANDLE         DW      0       ; Cur File Handle
FSPECWC        DB      64 DUP (0)  ; Arg FSpec

IVEC_SEG       DW      0       ; System Interrupt Vectors
FAR5h          DD      0       ; Org Int  5h Vector
FAR15h         DD      0       ;  "   "  15h  "
FAR1Ch         DD      0       ;  "   "  1Ch  "
FAR4Ah         DD      0       ;  "   "  4Ah  "
FAR8Eh         DD      0       ;  "   "  8Eh  "

VBUF_SEG       DW      0       ; Video Buffer Addr (Reset to B0/B8)
VBUF_PGOFS     DW      0       ; Offset per Page * Bytes
VBUF_SAV       DW      0       ; Page + Msg Offset
VTXT_LOC       DW      0       ; Msg Txt (USERMSG/ALAMMSG)
VBUF_MSG       DW      0       ; Msg Offset (40/80/132)
VBUF_ALM       DW      0       ;  "    "      "  (Alarm) 
VBUF_ENT       DW      0       ;  "    "      "  (Prompt)
VBUF_B800      DW      0B800h  ; Color Buffer (also VBUF_CO)
GBUF_SEG       DW      0A000h  ; Graphics area

COLWIDTH       DW      0       ;  "  Offset Nxt Row
COLWIDTH2      DW      0       ;  "  Offset Nxt Row
GRAF_FLAG      DB      0       ; 1=Graphics at A000h
XCOLS          DW      0       ; Word Columns

XMODE          DB      0       ; Byte Mode
XBYTES         DW      0       ; Word Bytes
XPAGE          DB      0       ; Byte Page

BYTECNT        DW      0       ; Total Bytes output
WAITCNT        DW      0       ; Reset from WAITMAX
SCCOLS         DB      0       ; Columns
SCROWS         DB      0       ; Rows

MSGCOLS        DW      40      ; Msg Len - All SysRQ (EACH line)
MSGCOLS2       DW      22      ; Msg Len - ENTER Msg (EACH line)

; Note: MUST be 5 lines, 40 Bytes each
DUMPMSG        DB      213,38 DUP(205),184
               DB      179,'  ',16
               DB      '  SysRQ :  Video Screen OUTPUT  '
               DB      17,'  ',179
               DB      179,'   { Press ALT to Ack }  Seg 0'
DUMPASC        DB      'xx00h   ',179
               DB      179,32,32
DUMPDRV        Label   Byte
               DB      16 DUP(' ')
BYTEASC        DB      'nn,nnn Bytes Total',2 DUP(' '),179
               DB      212,38 DUP(205),190

; Note: MUST be 5 lines, 40 Bytes each
USERMSG        DB      213,38 DUP(205),184
               DB      179,32,' SysRQ: The TIME is now '
USERTOD        DB      'hh:mm:ss xx ', 32,179
               DB      179,32,' ALARM Clock was set to '
USERALM        DB      'hh:mm:ss xx ', 32,179
               DB        179,'   { Use ALT key to continue ... }    ',179
               DB      212,38 DUP(205),190

; Note: MUST be 5 lines, 40 Bytes each
ALAMMSG        DB      213,38 DUP(205),184
               DB      179,'  SysRQ : Procedure ERROR Detected !  ',179
               DB      179,'       '
ALAMBAT        DB      '  ????????.???                 ',179
               DB      179,'      { Use ALT key to continue }     ',179
               DB      212,38 DUP(205),190

; Note: MUST be 5 lines, 40 Bytes each
ALTSMSG        DB      213,38 DUP(205),184
               DB      179,32,' SysRQ: Real Time CLOCK '
ALTSTOD        DB      'hh:mm:ss xx ', 32,179
               DB      179,32,' { ALT to Ack }   ALARM '
ALTSALM        DB      'hh:mm:ss xx ', 32,179
               DB      179,32,'  "SETALARM HH:MMxm" or '
               DB      '"ALARMOFF"  ', 32,179
               DB      212,38 DUP(205),190
ALTSALMX       DB      'is Disabled '

; Note: MUST be 5 lines, 22 Bytes each
ENTERMSG       DB      213,20 DUP(205),184
               DB      179,' SysRQ: Int8Eh Wait ',179
               DB      179,'  Press [ENTER] key ',179
               DB      179,'   to continue ...  ',179
               DB      212,20 DUP(205),190

FILEMSG        DB      13,10
               DB      16,' SysRQ PScrn  BSeg B'
DOSEG          DB      '800h   Page '
DOPAGE         DB      '0   Mode '
DOMODE         DB      'nn   Bios '
DOBYTES        DB      'nnnnn   Cols '
DOCOLS         DB      'nnn   Rows '
DOROWS         DB      'nn '
               DB      13,10
               DB      16,' Output to '
DOFSPEC        DB      64 DUP (32)
               DB      13,10,13,10
FILEML         EQU     $-FILEMSG

LOCKOLD        DB      0       ; Last State of Lock Keys
KBSTAT         DB      0       ; Kybd Stat Flag
TKSTAT         DB      0       ; 1=Hourly Chime (only once)
COMSTAT        DB      0FFh    ; Modem Flags: COMn
ZBYTE          DB      0
ZWORD          DW      0
DECIMAL        DB      8 DUP ('0'),' $'  ; Sp for DWord Mov

RTCBIN         DB      6 DUP(0)  ; BIOS RTC data
BIN_TOD        DB      4 DUP(0)  ; Binary
BIN_ALM        DB      0       ; Bin hh

ASC_TOD        DB      '00:00:00'  ; ASCII
ASC_TODL       EQU     $-ASC_TOD
MIDNIGHT       DB      ' xm ',0

ASC_ALM        DB      '00:00:00'  ; ASCII
ASC_ALML       EQU     $-ASC_ALM
MIDALARM       DB      ' xm ',0

CSR_LOC        Label   Word    ; Cursor Location
CSR_ROW        DB      0       ; Csr Row (0-43)
CSR_COL        DB      0       ; Csr Col (0-131)
MSG_LOC        Label   Word
               DB      6,0    ; Msg Row/Col
SAV_LOC        DW      0

ROOT           DB      'd:\',0  ; Root Path
RCC            DB      0       ; Return Code/Child
PROCTXT        DB      'Process :  ',0
PROCESS        DB      'SYSREQ.EXE',0

RCODE          Label   Word    ; Saved Error Code
RC             DB      0       ; al
RCE            DB      0       ; ah

; Ext'd Info
EXT_SAV        DW      5 DUP(0)  ; ax,bx,cx,es,di from Int 21h, Func 59h

ERR_MSG        DB      'Error #$'  ; Prefix
ERR_ASC        DB      'nnn ',247,'  ','$'
ERRADR         DW      0       ; Saved si (Msg)
ERR_END        DB      32,17,0,'$'
ERRFSA         DB      'File Spec. ',247,'  '
ERRFSAD        DB      64 DUP(0),'$'

ERRVOL         DB      'Volume ID  ',247,'  '
ERRVOLD        DB      64 DUP(0),'$'

ELOCUS         DB      'Locus  '
ERREXTD3       DB      'nnn ',247,'  $'
ECLASS         DB      'Class  '
ERREXTD2       DB      'nnn ',247,'  $'
EACTION        DB      'Action '
ERREXTD4       DB      'nnn ',247,'  $'

VERIFY         DB      'Disk Verify :  O'
VERFLG         DB      'xx',0

; ----------------------------------------------------------------------
; Data Constants
               .CONST

; Interrupt(s) Far Pointer Table
SYSRQ_FAR      DD      RESTART
PSCRN_FAR      DD      PRTSCRN
ALARM_FAR      DD      ALARM
UTICK_FAR      DD      TICKER
ENTER_FAR      DD      PROMPT

BIOS_SEG       DW      40h     ; ROM Bios RAM Data
VBUF_COM       DW      3624    ; R24 C53
VBUF_CO        DW      0B800h  ; if Mode 2, 3, etc.
VBUF_MONO      DW      0B000h  ; if Mode 7, 86 or 87
WAITMAX        DW      10000   ; Sec = nk-1 mSecs Print Scrn
WAITALT        DW      30000   ; Sec = nk-1 mSecs Query
CO_MSG         DB      27      ; Msg Color - Hi-Cyan (11) on Blue (16)
CO_COM         DB      112     ; COM   "   - Black on White (Rev)

ZERO           DB      0
SPACE          DB      ' '
DOLLAR         DB      '$'
HEXTABLE       DB      '0123456789ABCDEF'
COM_TXT        DB      ' 2: DTR Dsr RTS Cts Dcd o^o '
COM_LEN        EQU     $-COM_TXT

ERR_ALT        DB      'SysRQ :  Toggle  ALT  key to Retry,  ENTER '
               DB      ' key to Ignore or  ESC to Abort ',0,'$'
BELCRLF        DB      7
CRLF           DB      13,10,0,'$'

               INCLUDE StdError.Inc    ; Error Tables

BELL           DB      7,'$'
SUFF           DB      ' ',13,10,'$'
MSG_ENTER      DB      'Press ENTER to continue ...$'
CLR_SCR        DB      27,'[2J$'

DFS            DB      'C:\SYSRQ.SCR'  ; Default FSpec
DFSLEN         EQU     $-DFS
               DB      0

CRPT_MSG       DB      13,10,16,' SysRQ: '
               DB      'Resident program SYSREQ.EXE is Corrupt - '
               DB      'press any Key to re-start '
               DB      13,10,'$'

TSR_MSG        DB      13,10   ; always New Line
               DB      213,76 DUP(205),184,13,10
               DB      179,76 DUP(32),179,13,10
               DB      179,'  SysRQ Loader: Press [ Print Scrn ] key '
               DB      'to dump Text screen to \SysRQ.Scr  ',179,13,10
               DB      179,'  ',218,70 DUP(196),191,'  ',179,13,10
               DB      179,'  ',179,'  Version 1B  { LOCK keys ON with Risi'
               DB      'ng Tone, Falling Tone is OFF }  ',179,'  ',179,13,10
               DB      179,'  ',192,70 DUP(196),217,'  ',179,13,10
               DB      179,'   Press [ Alt+SysRQ ] key to display cur'
               DB      'rent setting of the AT Bios RTC    ',179,13,10
               DB      179,76 DUP(32),179,13,10
               DB      179,'   Alarm Clock :  Type "SETALARM hh:mmx" '
               DB      'to Set, or "ALARMOFF" to Disable   ',179,13,10
               DB      179,'   Windows ... :  Exec or Call INT4AH for'
               DB      ' Errors  { Use INT8EH to Pause }   ',179,13,10
               DB      179,76 DUP(32),179,13,10
               DB      179,' (c) 1995  Ben Ritchey Jr  Propriety '
               DB      'Licensed Use ONLY, All Rights Reserved ',179,13,10
               DB      212,76 DUP(205),190,13,10
               DB      '$'     ; End of Msg

; LoadHigh should be 32k or more - type MEM /M SYSREQ for actual
;   MEM TOTAL should be less AFTER SysReq is Loaded.
;     i.e. " LH /L:1,34049 SYSREQ.EXE " for 33.nk Max
;     ==>  Mod Code at SETSRQ: to " mov   bx,SRQPAGES " to Plug Max!  <==

SRQPAGES       DW      851h    ; TSR Pages (32k Exe +1k Stack +256 PSP) +1
; Actual value [ [ .EXE size +1024/400h Stack +256/100h PSP ] /16 ] +1

;*** End of SysReq.Inc ***

